summaryrefslogtreecommitdiffstats
path: root/chrome/browser/renderer_host
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-11 18:34:40 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-11 18:34:40 +0000
commite8dbd674b68f0261498ae901c0805278a0c7bea1 (patch)
tree3e8cee2336e8a29ab1725bd78bff0ef37e7a9672 /chrome/browser/renderer_host
parentea7452ec150026c4cef99a661a5afc32bec1749c (diff)
downloadchromium_src-e8dbd674b68f0261498ae901c0805278a0c7bea1.zip
chromium_src-e8dbd674b68f0261498ae901c0805278a0c7bea1.tar.gz
chromium_src-e8dbd674b68f0261498ae901c0805278a0c7bea1.tar.bz2
Rename RenderViewHostDelegate::FormFieldHistory to Autocomplete.
BUG=33032 TEST=none Review URL: http://codereview.chromium.org/815004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@41294 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/renderer_host')
-rw-r--r--chrome/browser/renderer_host/render_view_host.cc26
-rw-r--r--chrome/browser/renderer_host/render_view_host_delegate.cc4
-rw-r--r--chrome/browser/renderer_host/render_view_host_delegate.h30
3 files changed, 30 insertions, 30 deletions
diff --git a/chrome/browser/renderer_host/render_view_host.cc b/chrome/browser/renderer_host/render_view_host.cc
index da86877..4731684 100644
--- a/chrome/browser/renderer_host/render_view_host.cc
+++ b/chrome/browser/renderer_host/render_view_host.cc
@@ -1375,10 +1375,10 @@ void RenderViewHost::OnMsgPasswordFormsSeen(
void RenderViewHost::OnMsgFormFieldValuesSubmitted(
const webkit_glue::FormFieldValues& form) {
- RenderViewHostDelegate::FormFieldHistory* formfield_history_delegate =
- delegate_->GetFormFieldHistoryDelegate();
- if (formfield_history_delegate)
- formfield_history_delegate->FormFieldValuesSubmitted(form);
+ RenderViewHostDelegate::Autocomplete* autocomplete_delegate =
+ delegate_->GetAutocompleteDelegate();
+ if (autocomplete_delegate)
+ autocomplete_delegate->FormFieldValuesSubmitted(form);
RenderViewHostDelegate::AutoFill* autofill_delegate =
delegate_->GetAutoFillDelegate();
@@ -1580,16 +1580,16 @@ void RenderViewHost::OnQueryFormFieldAutofill(
RenderViewHostDelegate::AutoFill* autofill_delegate =
delegate_->GetAutoFillDelegate();
// If the AutoFill delegate has results to return, we don't need any results
- // from the FormFieldHistory delegate.
+ // from the Autocomplete delegate.
if (autofill_delegate &&
autofill_delegate->GetAutoFillSuggestions(query_id, field)) {
return;
}
- RenderViewHostDelegate::FormFieldHistory* formfield_history_delegate =
- delegate_->GetFormFieldHistoryDelegate();
- if (formfield_history_delegate &&
- formfield_history_delegate->GetFormFieldHistorySuggestions(
+ RenderViewHostDelegate::Autocomplete* autocomplete_delegate =
+ delegate_->GetAutocompleteDelegate();
+ if (autocomplete_delegate &&
+ autocomplete_delegate->GetAutocompleteSuggestions(
query_id, field.name(), field.value())) {
return;
}
@@ -1600,10 +1600,10 @@ void RenderViewHost::OnQueryFormFieldAutofill(
void RenderViewHost::OnRemoveAutofillEntry(const string16& field_name,
const string16& value) {
- RenderViewHostDelegate::FormFieldHistory* formfield_history_delegate =
- delegate_->GetFormFieldHistoryDelegate();
- if (formfield_history_delegate)
- formfield_history_delegate->RemoveFormFieldHistoryEntry(field_name, value);
+ RenderViewHostDelegate::Autocomplete* autocomplete_delegate =
+ delegate_->GetAutocompleteDelegate();
+ if (autocomplete_delegate)
+ autocomplete_delegate->RemoveAutocompleteEntry(field_name, value);
}
void RenderViewHost::OnFillAutoFillFormData(int query_id,
diff --git a/chrome/browser/renderer_host/render_view_host_delegate.cc b/chrome/browser/renderer_host/render_view_host_delegate.cc
index dcf26f5..eb4c8ca 100644
--- a/chrome/browser/renderer_host/render_view_host_delegate.cc
+++ b/chrome/browser/renderer_host/render_view_host_delegate.cc
@@ -47,8 +47,8 @@ RenderViewHostDelegate::GetFavIconDelegate() {
return NULL;
}
-RenderViewHostDelegate::FormFieldHistory*
-RenderViewHostDelegate::GetFormFieldHistoryDelegate() {
+RenderViewHostDelegate::Autocomplete*
+RenderViewHostDelegate::GetAutocompleteDelegate() {
return NULL;
}
diff --git a/chrome/browser/renderer_host/render_view_host_delegate.h b/chrome/browser/renderer_host/render_view_host_delegate.h
index f4e088e..d908e1f 100644
--- a/chrome/browser/renderer_host/render_view_host_delegate.h
+++ b/chrome/browser/renderer_host/render_view_host_delegate.h
@@ -359,31 +359,31 @@ class RenderViewHostDelegate {
const GURL& icon_url) = 0;
};
- // FormFieldHistory ----------------------------------------------------------
- // Interface for FormFieldHistory-related functions.
+ // Autocomplete --------------------------------------------------------------
+ // Interface for Autocomplete-related functions.
- class FormFieldHistory {
+ class Autocomplete {
public:
// Forms fillable by FormFieldHistory have been detected in the page.
virtual void FormFieldValuesSubmitted(
const webkit_glue::FormFieldValues& form) = 0;
// Called to retrieve a list of suggestions from the web database given
// the name of the field |field_name| and what the user has already typed
// in the field |user_text|. Appeals to the database thread to perform the
- // query. When the database thread is finished, the FormFieldHistory manager
- // retrieves the calling RenderViewHost and then passes the vector of
- // suggestions to RenderViewHost::AutocompleteSuggestionsReturned.
- // Return true to indicate that FormFieldHistorySuggestionsReturned will be
+ // query. When the database thread is finished, the AutocompleteHistory
+ // manager retrieves the calling RenderViewHost and then passes the vector
+ // of suggestions to RenderViewHost::AutocompleteSuggestionsReturned.
+ // Returns true to indicate that FormFieldHistorySuggestionsReturned will be
// called.
- virtual bool GetFormFieldHistorySuggestions(int query_id,
- const string16& field_name,
- const string16& user_text) = 0;
+ virtual bool GetAutocompleteSuggestions(int query_id,
+ const string16& field_name,
+ const string16& user_text) = 0;
// Called when the user has indicated that she wants to remove the specified
- // FormFieldHistory suggestion from the database.
- virtual void RemoveFormFieldHistoryEntry(const string16& field_name,
- const string16& value) = 0;
+ // Autocomplete suggestion from the database.
+ virtual void RemoveAutocompleteEntry(const string16& field_name,
+ const string16& value) = 0;
};
// AutoFill ------------------------------------------------------------------
@@ -449,7 +449,7 @@ class RenderViewHostDelegate {
virtual Save* GetSaveDelegate();
virtual Printing* GetPrintingDelegate();
virtual FavIcon* GetFavIconDelegate();
- virtual FormFieldHistory* GetFormFieldHistoryDelegate();
+ virtual Autocomplete* GetAutocompleteDelegate();
virtual AutoFill* GetAutoFillDelegate();
virtual BookmarkDrag* GetBookmarkDragDelegate();
@@ -359,31 +359,31 @@ class RenderViewHostDelegate {
public:
- // Forms fillable by FormFieldHistory have been detected in the page.
+ // Forms fillable by Autocomplete have been detected in the page.
virtual void FormFieldValuesSubmitted(
const webkit_glue::FormFieldValues& form) = 0;